# Installation Guide
GNATSS requires Python v3.10 or greater to run. If you have a conda installation, we recommend creating a fresh environment to install GNATSS in.

```
conda create -n gnatss -c conda-forge --yes python=3.10 ipykernel
conda activate gnatss
```

Once you have the appropriate python environment enabled, GNATSS may be installed via pip:

```
pip install gnatss
```
